@@ -348,4 +348,4 @@ def train_new_model(dataframe, input_dim, hidden_dim, model_path, learning_rate=
 
     save_models(model, model_path)
 
-    return model
\ No newline at end of file
+    return running_loss, model
\ No newline at end of file
